# Tenzir Platform CLI

This CLI can be used to interact with the APIs exposed by the Tenzir Platform.

See `docs.tenzir.com` for more detailed user-facing documentation.

For interacting with private instances of the platform, set these
environment variables to their respective local values:

	TENZIR_PLATFORM_CLI_API_ENDPOINT
	TENZIR_PLATFORM_CLI_ISSUER_URL
	TENZIR_PLATFORM_CLI_CLIENT_ID
